==> QupZilla-2.0.1.tar.xz: QupZilla-2.0.1/src/plugins/StatusBarIcons/translations/ca_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca_ES" version="2.1">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="32"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>Modifica els ajustaments de càrrega d&apos;imatges globalment i per lloc</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="56"/>
        <source>Current Page Settings</source>
        <translation>Ajustaments actuals de la pàgina</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="59"/>
        <source>Disable loading images (temporarily)</source>
        <translation>Deshabilita la càrrega d&apos;imatges (temporalment)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="62"/>
        <source>Enable loading images (temporarily)</source>
        <translation>Habilita la càrrega d&apos;imatges (temporalment)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="66"/>
        <source>Global Settings</source>
        <translation>Ajustaments globals</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="68"/>
        <source>Automatically load images</source>
        <translation>Carrega les imatges automàticament</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="33"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>Modifica els ajustaments de JavaScript globalment i per lloc</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="50"/>
        <source>Current Page Settings</source>
        <translation>Ajustaments actuals de la pàgina</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="53"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>Deshabilita JavaScript (temporalment)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="56"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>Habilita JavaScript (temporalment)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="65"/>
        <source>Global Settings</source>
        <translation>Ajustaments globals</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="66"/>
        <source>Manage JavaScript settings</source>
        <translation>Configura JavaScript</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="64"/>
        <source>Proxy Configuration</source>
        <translation>Configuració del servidor intermediari</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="66"/>
        <source>Select proxy</source>
        <translation>Selecciona un servidor intermediari</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="80"/>
        <source>Empty</source>
        <translation>Buit</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="84"/>
        <source>Manage proxies</source>
        <translation>Gestiona els servidors intermediaris</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="97"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>Mostra l&apos;estat de la xarxa i gestiona el servidor intermediari&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Xarxa:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Servidor intermediari:&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="100"/>
        <source>Connected</source>
        <translation>Connectat</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="103"/>
        <source>Offline</source>
        <translation>Desconnectat</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="108"/>
        <source>System proxy</source>
        <translation>Servidor intermediari del sistema</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="112"/>
        <source>No proxy</source>
        <translation>Sense servidor intermediari</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="116"/>
        <source>User defined</source>
        <translation>Definit per l&apos;usuari</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>Gestor de servidors intermediaris</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>Selecciona un servidor intermediari:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Add proxy</source>
        <translation>Afegeix un servidor intermediari</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>Suprimeix el servidor intermediari </translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>No hi ha servidors intermediaris. Podeu afegir-ne clicant al botó d&apos;&lt;b&gt;Afegeix&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>Tots els canvis s&apos;han de guardar amb el botó  &lt;b&gt;Desa&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Name of proxy:</source>
        <translation>Nom del servidor intermediari:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Remove current proxy</source>
        <translation>Suprimeix el servidor intermediari actual</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Are you sure you want to remove current proxy?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>Formulari</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="23"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="28"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="39"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="76"/>
        <source>Username:</source>
        <translation>Nom d&apos;usuari:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="86"/>
        <source>Password:</source>
        <translation>Contrasenya:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <source>S&amp;ystem proxy configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="118"/>
        <source>&amp;Manual configuration</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>Icones de la barra d&apos;estat</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Icones de la barra d&apos;estat&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>Aquestes icones es mostraran a la barra d&apos;estat:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>Icona de la imatge</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>Icona de JavaScript</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>Icona de xarxa</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="118"/>
        <source>Zoom widget</source>
        <translation>Giny de zoom</translation>
    </message>
</context>
<context>
    <name>SBI_ZoomWidget</name>
    <message>
        <location filename="../sbi_zoomwidget.cpp" line="47"/>
        <source>Zoom: %1%</source>
        <translation>Zoom: %1%</translation>
    </message>
</context>
</TS>

==> QupZilla-2.2.5.tar.xz: QupZilla-2.2.5/src/plugins/StatusBarIcons/translations/ca_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca_ES" version="2.1">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="33"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>Modifica els ajustaments de càrrega d&apos;imatges globalment i per lloc</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="57"/>
        <source>Current Page Settings</source>
        <translation>Ajustaments actuals de la pàgina</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="60"/>
        <source>Disable loading images (temporarily)</source>
        <translation>Deshabilita la càrrega d&apos;imatges (temporalment)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="63"/>
        <source>Enable loading images (temporarily)</source>
        <translation>Habilita la càrrega d&apos;imatges (temporalment)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="67"/>
        <source>Global Settings</source>
        <translation>Ajustaments globals</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="69"/>
        <source>Automatically load images</source>
        <translation>Carrega les imatges automàticament</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="34"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>Modifica els ajustaments de JavaScript globalment i per lloc</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="51"/>
        <source>Current Page Settings</source>
        <translation>Ajustaments actuals de la pàgina</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="54"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>Deshabilita JavaScript (temporalment)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="57"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>Habilita JavaScript (temporalment)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="66"/>
        <source>Global Settings</source>
        <translation>Ajustaments globals</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="67"/>
        <source>Manage JavaScript settings</source>
        <translation>Configura JavaScript</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="65"/>
        <source>Proxy Configuration</source>
        <translation>Configuració del servidor intermediari</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="67"/>
        <source>Select proxy</source>
        <translation>Selecciona un servidor intermediari</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="81"/>
        <source>Empty</source>
        <translation>Buit</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="85"/>
        <source>Manage proxies</source>
        <translation>Gestiona els servidors intermediaris</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="98"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>Mostra l&apos;estat de la xarxa i gestiona el servidor intermediari&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Xarxa:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Servidor intermediari:&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="101"/>
        <source>Connected</source>
        <translation>Connectat</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="104"/>
        <source>Offline</source>
        <translation>Desconnectat</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="109"/>
        <source>System proxy</source>
        <translation>Servidor intermediari del sistema</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="113"/>
        <source>No proxy</source>
        <translation>Sense servidor intermediari</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="117"/>
        <source>User defined</source>
        <translation>Definit per l&apos;usuari</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>Gestor de servidors intermediaris</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>Selecciona un servidor intermediari:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Add proxy</source>
        <translation>Afegeix un servidor intermediari</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>Suprimeix el servidor intermediari </translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>No hi ha servidors intermediaris. Podeu afegir-ne clicant al botó d&apos;&lt;b&gt;Afegeix&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>Tots els canvis s&apos;han de guardar amb el botó  &lt;b&gt;Desa&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Name of proxy:</source>
        <translation>Nom del servidor intermediari:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Remove current proxy</source>
        <translation>Suprimeix el servidor intermediari actual</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Are you sure you want to remove current proxy?</source>
        <translation>Esteu segur que voleu suprimir el servidor intermediari actual?</translation>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>Formulari</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="23"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="28"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="39"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="76"/>
        <source>Username:</source>
        <translation>Nom d&apos;usuari:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="86"/>
        <source>Password:</source>
        <translation>Contrasenya:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <source>S&amp;ystem proxy configuration</source>
        <translation>Configuració del servidor intermediari del s&amp;istema</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="118"/>
        <source>&amp;Manual configuration</source>
        <translation>Configuració &amp;manual</translation>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>Icones de la barra d&apos;estat</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Icones de la barra d&apos;estat&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>Aquestes icones es mostraran a la barra d&apos;estat:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>Icona de la imatge</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>Icona de JavaScript</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>Icona de xarxa</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="118"/>
        <source>Zoom widget</source>
        <translation>Giny de zoom</translation>
    </message>
</context>
<context>
    <name>SBI_ZoomWidget</name>
    <message>
        <location filename="../sbi_zoomwidget.cpp" line="48"/>
        <source>Zoom: %1%</source>
        <translation>Zoom: %1%</translation>
    </message>
</context>
</TS>
